/* 
 * tkMacConsole.c --
 *
 *	This file contains Macintosh-specific procedures for the notifier,
 *	which is the lowest-level part of the Tcl event loop.  This file
 *	works together with ../generic/tclNotify.c.
 *
 * Copyright (c) 1995-1996 Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * SCCS: @(#) tkMacConsole.c 1.15 96/03/08 14:03:46
 */

#ifndef __CONSOLE__
#include <console.h>
#endif

#include <Events.h>
#include <SIOUX.h> 
#include <GUSI.h> 

#include "tcl.h"
#include "tk.h"
#include "tkMacInt.h"

typedef int (*TclMacConvertEventPtr) _ANSI_ARGS_((EventRecord *eventPtr));

/*
 * Hack to allow Mac Tk to override the TclGetStdChannels function.
 */
 
Tcl_Interp *gStdoutInterp = NULL;
static int GUSISpinFunction _ANSI_ARGS_((spin_msg msg, long param));
void 	TclMacSetEventProc _ANSI_ARGS_((TclMacConvertEventPtr procPtr));
int 	TkMacConvertEvent _ANSI_ARGS_((EventRecord *eventPtr));


/*
 *----------------------------------------------------------------------
 *
 * InstallConsole, RemoveConsole, etc. --
 *
 *	The following functions provide the UI for the console package.
 *	Users wishing to replace SIOUX with their own console package 
 *	need only provide the four functions below in a library.
 *
 * Results:
 *	See SIOUX documentation for details.
 *
 * Side effects:
 *	See SIOUX documentation for details.
 *
 *----------------------------------------------------------------------
 */

short 
InstallConsole(short fd)
{
#pragma unused (fd)

	return 0;
}

void 
RemoveConsole(void)
{
}

long 
WriteCharsToConsole(char *buffer, long n)
{
    TkConsolePrint(gStdoutInterp, NULL, buffer, n);
    return n;
}

long 
ReadCharsFromConsole(char *buffer, long n)
{
    return 0;
}

extern char *
__ttyname(long fildes)
{
    static char *__devicename = "null device";

    if (fildes >= 0 && fildes <= 2) {
	return (__devicename);
    }
    
    return (0L);
}

short
SIOUXHandleOneEvent(EventRecord *event)
{
    return 0;
}

/*
 *----------------------------------------------------------------------
 *
 * TclMacConsoleInit --
 *
 *	This procedure calls initalization routines to set up a simple
 *	console on a Macintosh.  This is necessary as the Mac doesn't
 *	have a stdout & stderr by default.
 *
 * Results:
 *	Returns TCL_OK if everything went fine.  If it didn't the 
 *	application should probably fail.
 *
 * Side effects:
 *	Inits the appropiate console package.
 *
 *----------------------------------------------------------------------
 */

int
TclMacConsoleInit()
{
    GUSIDefaultSetup();
    GUSISetHook(GUSI_SpinHook, (GUSIHook) GUSISpinFunction);

    TclMacSetEventProc(TkMacConvertEvent);
    TkConsoleCreate();
    
    return TCL_OK;
}

/*
 *----------------------------------------------------------------------
 *
 * GUSISpinFunction --
 *
 *	Spins.
 *
 * Results:
 *	Returns .
 *
 * Side effects:
 *	None.
 *
 *----------------------------------------------------------------------
 */

static int
GUSISpinFunction(msg, param)
    spin_msg msg;
    long param;
{
    EventRecord ev;
    
    WaitNextEvent(0, &ev, 0, NULL);
    return 0;
}
void
tkMacInstallMWConsole(Tcl_Interp *interp)
{
    gStdoutInterp = interp;
}
